Evaluate the loss function of the cod model across a range of tau (precision parameter) values
optcodsmooth.RdEvaluate the loss function of the cod model across a range of tau (precision parameter) values
Usage
optcodsmooth(
tr,
logtaulb = -4,
logtauub = 35,
res = 5,
startpc = 75,
endpc = 100,
nobj = 100,
ipw = NULL,
ncpu = 1,
tol = 0.001
)Arguments
- tr
A phylogenetic tree in ape::phylo format
- logtaulb
Lower bound of precision parameteters
- logtauub
Upper bound of precision parameteters
- res
Number of tau values to evaluate
- startpc
The initial per cent of nodes in the tree counting from root to tips where the loss function will be evaluated
- endpc
The final per cent of nodes in the tree counting from root to tips where the loss function will be evaluated
- nobj
The integer number of points along the tree where the loss function will be evaluated. If Inf, will use all points between startpc and endpc, but may be slow.
- ipw
Optional inverse probability weights for each sample